@@ -4,16 +4,16 @@
 #'
 #' @export
 
-## Helper function for draft.software
+# Helper function for draft.software
 
 ds.package <- function(package, author, year, title, version, source)
 {
-  ## 1  Bibliographic info: author, year, title, details
+  # 1  Bibliographic info: author, year, title, details
   cit <- citation(package, lib.loc=c(file.path(boot.dir(), "library"),
                                      .libPaths()))[1]
   bib <- as.list(toBibtex(cit))
   key <- sub(",$", paste0(package,","), bib[[1]])  # add package name
-  ## Treat null and NA (from mapply) the same, must test null first
+  # Treat null and NA (from mapply) the same, must test null first
   author <- if(is.null(author) || is.na(author)) bib$author
             else paste0("  author = {", author, "},")
   year <- if(is.null(year) || is.na(year)) bib$year
@@ -32,10 +32,11 @@ ds.package <- function(package, author, year, title, version, source)
                     thesis=c(bib$type, bib$school),
                     c(bib$edition, bib$doi))
 
-  ## 2  Package info: version, source
+  # 2  Package info: version, source
   pkg <- packageDescription(package, lib.loc=c(file.path(boot.dir(), "library"),
                                                .libPaths()))
   repotype <- if(isTRUE(pkg$Repository == "CRAN")) "CRAN"
+              else if(isTRUE(grepl("r-universe", pkg$Repository))) "Runiverse"
               else if(isTRUE(pkg$RemoteType == "github")) "GitHub"
               else if(!is.null(pkg$Repository)) pkg$Repository
               else NA_character_
@@ -54,11 +55,15 @@ ds.package <- function(package, author, year, title, version, source)
                                    "/", pkg$GithubRepo,
                                    if(!is.null(pkg$GithubSubdir))
                                      paste0("/", pkg$GithubSubdir),
-                                   "@", substring(pkg$GithubSHA1, 1, 7)))
+                                   "@", substring(pkg$GithubSHA1, 1, 7)),
+                     Runiverse=paste0(sub("https://.*?/", "", pkg$RemoteUrl),
+                                      if(pkg$Package != basename(pkg$RemoteUrl))
+                                        paste0("/", pkg$Package),
+                                      "@", substring(pkg$RemoteSha, 1, 7)))
   }
   source <- paste0("  source = {", source, "},")
 
-  ## 3  Combine and format metadata
+  # 3  Combine and format metadata
   fields <- c(author, year, title, details, version, source)
   fields <- strsplit(fields, "=")  # align at equals sign
   fields <- paste0(format(sapply(fields,"[",1)), "=", sapply(fields,"[",2))
